==> pdal-1.5.0-2-armv6h.pkg.tar.xz: usr/include/pdal/filters/StreamCallbackFilter.hpp <==
/******************************************************************************
* Copyright (c) 2015, Hobu Inc. (info@hobu.co)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/

#pragma once

#include <pdal/Filter.hpp>
#include <pdal/plugin.hpp>

#include <functional>

extern "C" int32_t StreamCallbackFilter_ExitFunc();
extern "C" PF_ExitFunc StreamCallbackFilter_InitPlugin();

namespace pdal
{

class PDAL_DLL StreamCallbackFilter : public Filter
{
public:
    static void * create();
    static int32_t destroy(void *);
    std::string getName() const
        { return "filters.streamcallback"; }

    StreamCallbackFilter()
    {}

    typedef std::function<bool(PointRef&)> CallbackFunc;
    void setCallback(CallbackFunc cb)
        { m_callback = cb; }

private:
    virtual bool processOne(PointRef& point)
    {
        if (m_callback)
            return m_callback(point);
        return false;
    }

    CallbackFunc m_callback;

    StreamCallbackFilter&
        operator=(const StreamCallbackFilter&); // not implemented
    StreamCallbackFilter(const StreamCallbackFilter&); // not implemented
};

} // namespace pdal

==> pdal-1.6.0-3-armv6h.pkg.tar.xz: usr/include/pdal/filters/StreamCallbackFilter.hpp <==
/******************************************************************************
* Copyright (c) 2015, Hobu Inc. (info@hobu.co)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/

#pragma once

#include <pdal/Filter.hpp>
#include <pdal/plugin.hpp>

#include <functional>

extern "C" int32_t StreamCallbackFilter_ExitFunc();
extern "C" PF_ExitFunc StreamCallbackFilter_InitPlugin();

namespace pdal
{

class PDAL_DLL StreamCallbackFilter : public Filter
{
public:
    static void * create();
    static int32_t destroy(void *);
    std::string getName() const
        { return "filters.streamcallback"; }

    StreamCallbackFilter()
    {}

    typedef std::function<bool(PointRef&)> CallbackFunc;
    void setCallback(CallbackFunc cb)
        { m_callback = cb; }

private:
    virtual void filter(PointView& view)
    {
        PointRef p(view, 0);
        for (PointId idx = 0; idx < view.size(); ++idx)
        {
            p.setPointId(idx);
            processOne(p);
        }
    }

    virtual bool processOne(PointRef& point)
    {
        if (m_callback)
            return m_callback(point);
        return false;
    }

    CallbackFunc m_callback;

    StreamCallbackFilter&
        operator=(const StreamCallbackFilter&); // not implemented
    StreamCallbackFilter(const StreamCallbackFilter&); // not implemented
};

} // namespace pdal
